aboutsummaryrefslogtreecommitdiff
path: root/contrib
diff options
context:
space:
mode:
authorTomo Ueda <[email protected]>2021-09-02 12:54:43 -0700
committerTomo Ueda <[email protected]>2021-09-02 12:54:43 -0700
commitf5c716526aaafb318a98e974c8b2fbe02870646b (patch)
treee14145656fcff86ec2c7a1ecf4ad28e0b40f36aa /contrib
parents/DOGE/DIS/g (diff)
downloaddiscoin-f5c716526aaafb318a98e974c8b2fbe02870646b.tar.xz
discoin-f5c716526aaafb318a98e974c8b2fbe02870646b.zip
really s/doge/dis/g this time
Diffstat (limited to 'contrib')
-rw-r--r--contrib/README.md12
-rw-r--r--contrib/debian/README.md16
-rw-r--r--contrib/debian/control22
-rw-r--r--contrib/debian/dogecoin-qt.desktop6
-rw-r--r--contrib/debian/dogecoin-qt.install12
-rw-r--r--contrib/debian/dogecoin-qt.lintian-overrides2
-rw-r--r--contrib/debian/dogecoin-qt.manpages2
-rw-r--r--contrib/debian/dogecoin-qt.protocol4
-rw-r--r--contrib/debian/dogecoin-tx.bash-completion2
-rw-r--r--contrib/debian/dogecoin-tx.install2
-rw-r--r--contrib/debian/dogecoin-tx.manpages2
-rw-r--r--contrib/debian/dogecoind.bash-completion4
-rw-r--r--contrib/debian/dogecoind.examples2
-rw-r--r--contrib/debian/dogecoind.install4
-rw-r--r--contrib/debian/dogecoind.lintian-overrides2
-rw-r--r--contrib/debian/dogecoind.manpages4
-rw-r--r--contrib/debian/examples/dogecoin.conf20
-rwxr-xr-xcontrib/debian/rules6
-rw-r--r--contrib/debian/watch2
-rwxr-xr-xcontrib/devtools/gen-manpages.sh12
-rw-r--r--contrib/dogecoind.bash-completion14
-rwxr-xr-xcontrib/gitian-build.sh62
-rw-r--r--contrib/gitian-descriptors/README.md4
-rw-r--r--contrib/gitian-descriptors/gitian-linux.yml12
-rw-r--r--contrib/gitian-descriptors/gitian-osx-signer.yml10
-rw-r--r--contrib/gitian-descriptors/gitian-osx.yml12
-rw-r--r--contrib/gitian-descriptors/gitian-win-signer.yml8
-rw-r--r--contrib/gitian-descriptors/gitian-win.yml14
-rw-r--r--contrib/linearize/README.md4
-rw-r--r--contrib/linearize/example-linearize.cfg6
-rwxr-xr-xcontrib/macdeploy/DS_Storebin15364 -> 15357 bytes
-rwxr-xr-xcontrib/macdeploy/custom_dsstore.py4
-rw-r--r--contrib/qos/README.md2
-rw-r--r--contrib/rpm/bitcoin.spec22
-rw-r--r--contrib/snap/README.md4
-rw-r--r--contrib/snap/snapcraft.yaml30
-rwxr-xr-xcontrib/verify-commits/pre-push-hook.sh2
37 files changed, 174 insertions, 174 deletions
diff --git a/contrib/README.md b/contrib/README.md
index 793c757a1..74ac7b89d 100644
--- a/contrib/README.md
+++ b/contrib/README.md
@@ -13,7 +13,7 @@ Construct a linear, no-fork, best version of the blockchain.
### [Qos](/contrib/qos) ###
-A Linux bash script that will set up traffic control (tc) to limit the outgoing bandwidth for connections to the Dogecoin network. This means one can have an always-on dogecoind instance running, and another local dogecoind/dogecoin-qt instance which connects to this node and receives blocks from it.
+A Linux bash script that will set up traffic control (tc) to limit the outgoing bandwidth for connections to the Dogecoin network. This means one can have an always-on discoind instance running, and another local discoind/discoin-qt instance which connects to this node and receives blocks from it.
### [Seeds](/contrib/seeds) ###
Utility to generate the pnSeed[] array that is compiled into the client.
@@ -22,8 +22,8 @@ Build Tools and Keys
---------------------
### [Debian](/contrib/debian) ###
-Contains files used to package dogecoind/dogecoin-qt
-for Debian-based Linux systems. If you compile dogecoind/dogecoin-qt yourself, there are some useful files here.
+Contains files used to package discoind/discoin-qt
+for Debian-based Linux systems. If you compile discoind/discoin-qt yourself, there are some useful files here.
### [Gitian-descriptors](/contrib/gitian-descriptors) ###
Notes on getting Gitian builds up and running using KVM.
@@ -35,13 +35,13 @@ PGP keys used for signing Dogecoin Core [Gitian release](/doc/release-process.md
Scripts and notes for Mac builds.
### [RPM](/contrib/rpm) ###
-RPM spec file for building dogecoin-core on RPM based distributions
+RPM spec file for building discoin-core on RPM based distributions
### [Gitian-build](/contrib/gitian-build.sh) ###
Script for running full Gitian builds.
### [Snap](/contrib/snap) ###
-snapcraft.yaml file for building and distributing dogecoin-core with Snapcraft.
+snapcraft.yaml file for building and distributing discoin-core with Snapcraft.
Test and Verify Tools
---------------------
@@ -50,4 +50,4 @@ Test and Verify Tools
Utilities to generate test vectors for the data-driven Dogecoin tests.
### [Verify Binaries](/contrib/verifybinaries) ###
-This script attempts to download and verify the signature file SHA256SUMS.asc from dogecoin.com.
+This script attempts to download and verify the signature file SHA256SUMS.asc from discoin.com.
diff --git a/contrib/debian/README.md b/contrib/debian/README.md
index a938dc913..447e7513c 100644
--- a/contrib/debian/README.md
+++ b/contrib/debian/README.md
@@ -1,21 +1,21 @@
Debian
====================
-This directory contains files used to package dogecoind/dogecoin-qt
-for Debian-based Linux systems. If you compile dogecoind/dogecoin-qt yourself, there are some useful files here.
+This directory contains files used to package discoind/discoin-qt
+for Debian-based Linux systems. If you compile discoind/discoin-qt yourself, there are some useful files here.
-## dogecoin: URI support ##
+## discoin: URI support ##
-dogecoin-qt.desktop (Gnome / Open Desktop)
+discoin-qt.desktop (Gnome / Open Desktop)
To install:
- sudo desktop-file-install dogecoin-qt.desktop
+ sudo desktop-file-install discoin-qt.desktop
sudo update-desktop-database
If you build yourself, you will either need to modify the paths in
-the .desktop file or copy or symlink your dogecoin-qt binary to `/usr/bin`
-and the `../../share/pixmaps/dogecoin128.png` to `/usr/share/pixmaps`
+the .desktop file or copy or symlink your discoin-qt binary to `/usr/bin`
+and the `../../share/pixmaps/discoin128.png` to `/usr/share/pixmaps`
-dogecoin-qt.protocol (KDE)
+discoin-qt.protocol (KDE)
diff --git a/contrib/debian/control b/contrib/debian/control
index d5a4c78da..9687ba844 100644
--- a/contrib/debian/control
+++ b/contrib/debian/control
@@ -1,4 +1,4 @@
-Source: dogecoin
+Source: discoin
Section: utils
Priority: optional
Maintainer: Matt Corallo <[email protected]>
@@ -26,11 +26,11 @@ Build-Depends: debhelper,
python,
libzmq3-dev
Standards-Version: 3.9.2
-Homepage: http://www.dogecoin.com/
-Vcs-Git: git://github.com/dogecoin/dogecoin.git
-Vcs-Browser: http://github.com/dogecoin/dogecoin
+Homepage: http://www.discoin.com/
+Vcs-Git: git://github.com/discoin/discoin.git
+Vcs-Browser: http://github.com/discoin/discoin
-Package: dogecoind
+Package: discoind
Architecture: any
Depends: ${shlibs:Depends}, ${misc:Depends}
Description: peer-to-peer network based digital currency - daemon
@@ -43,10 +43,10 @@ Description: peer-to-peer network based digital currency - daemon
Full transaction history is stored locally at each client. This
requires 20+ GB of space, slowly growing.
.
- This package provides the daemon, dogecoind, and the CLI tool
- dogecoin-cli to interact with the daemon.
+ This package provides the daemon, discoind, and the CLI tool
+ discoin-cli to interact with the daemon.
-Package: dogecoin-qt
+Package: discoin-qt
Architecture: any
Depends: ${shlibs:Depends}, ${misc:Depends}
Description: peer-to-peer network based digital currency - Qt GUI
@@ -58,7 +58,7 @@ Description: peer-to-peer network based digital currency - Qt GUI
.
This package provides Dogecoin-Qt, a GUI for Dogecoin based on Qt.
-Package: dogecoin-tx
+Package: discoin-tx
Architecture: any
Depends: ${shlibs:Depends}, ${misc:Depends}
Description: peer-to-peer digital currency - standalone transaction tool
@@ -68,6 +68,6 @@ Description: peer-to-peer digital currency - standalone transaction tool
transact directly with each other, with the help of a P2P network to
check for double-spending.
.
- This package provides dogecoin-tx, a command-line transaction creation
- tool which can be used without a dogecoin daemon. Some means of
+ This package provides discoin-tx, a command-line transaction creation
+ tool which can be used without a discoin daemon. Some means of
exchanging minimal transaction data with peers is still required.
diff --git a/contrib/debian/dogecoin-qt.desktop b/contrib/debian/dogecoin-qt.desktop
index e93fd071f..6f7d8569d 100644
--- a/contrib/debian/dogecoin-qt.desktop
+++ b/contrib/debian/dogecoin-qt.desktop
@@ -4,9 +4,9 @@ Comment=Connect to the Dogecoin P2P Network
Comment[de]=Verbinde mit dem Dogecoin peer-to-peer Netzwerk
Comment[fr]=Dogecoin, monnaie virtuelle cryptographique pair à pair
Comment[tr]=Dogecoin, eşten eşe kriptografik sanal para birimi
-Exec=dogecoin-qt %u
+Exec=discoin-qt %u
Terminal=false
Type=Application
-Icon=dogecoin128
-MimeType=x-scheme-handler/dogecoin;
+Icon=discoin128
+MimeType=x-scheme-handler/discoin;
Categories=Office;Finance;
diff --git a/contrib/debian/dogecoin-qt.install b/contrib/debian/dogecoin-qt.install
index b33910e50..9320f3612 100644
--- a/contrib/debian/dogecoin-qt.install
+++ b/contrib/debian/dogecoin-qt.install
@@ -1,6 +1,6 @@
-usr/local/bin/dogecoin-qt usr/bin
-share/pixmaps/dogecoin32.xpm usr/share/pixmaps
-share/pixmaps/dogecoin16.xpm usr/share/pixmaps
-share/pixmaps/dogecoin128.png usr/share/pixmaps
-debian/dogecoin-qt.desktop usr/share/applications
-debian/dogecoin-qt.protocol usr/share/kde4/services/
+usr/local/bin/discoin-qt usr/bin
+share/pixmaps/discoin32.xpm usr/share/pixmaps
+share/pixmaps/discoin16.xpm usr/share/pixmaps
+share/pixmaps/discoin128.png usr/share/pixmaps
+debian/discoin-qt.desktop usr/share/applications
+debian/discoin-qt.protocol usr/share/kde4/services/
diff --git a/contrib/debian/dogecoin-qt.lintian-overrides b/contrib/debian/dogecoin-qt.lintian-overrides
index f5c972923..71f0b1e55 100644
--- a/contrib/debian/dogecoin-qt.lintian-overrides
+++ b/contrib/debian/dogecoin-qt.lintian-overrides
@@ -1,2 +1,2 @@
# Linked code is Expat - only Debian packaging is GPL-2+
-dogecoin-qt: possible-gpl-code-linked-with-openssl
+discoin-qt: possible-gpl-code-linked-with-openssl
diff --git a/contrib/debian/dogecoin-qt.manpages b/contrib/debian/dogecoin-qt.manpages
index 2a6af96e6..1d2cbd708 100644
--- a/contrib/debian/dogecoin-qt.manpages
+++ b/contrib/debian/dogecoin-qt.manpages
@@ -1 +1 @@
-doc/man/dogecoin-qt.1
+doc/man/discoin-qt.1
diff --git a/contrib/debian/dogecoin-qt.protocol b/contrib/debian/dogecoin-qt.protocol
index 0d880761e..e0fe672a5 100644
--- a/contrib/debian/dogecoin-qt.protocol
+++ b/contrib/debian/dogecoin-qt.protocol
@@ -1,6 +1,6 @@
[Protocol]
-exec=dogecoin-qt '%u'
-protocol=dogecoin
+exec=discoin-qt '%u'
+protocol=discoin
input=none
output=none
helper=true
diff --git a/contrib/debian/dogecoin-tx.bash-completion b/contrib/debian/dogecoin-tx.bash-completion
index 47712d68c..a39268a4c 100644
--- a/contrib/debian/dogecoin-tx.bash-completion
+++ b/contrib/debian/dogecoin-tx.bash-completion
@@ -1 +1 @@
-contrib/dogecoin-tx.bash-completion dogecoin-tx
+contrib/discoin-tx.bash-completion discoin-tx
diff --git a/contrib/debian/dogecoin-tx.install b/contrib/debian/dogecoin-tx.install
index c176b49c4..0e7862170 100644
--- a/contrib/debian/dogecoin-tx.install
+++ b/contrib/debian/dogecoin-tx.install
@@ -1 +1 @@
-usr/local/bin/dogecoin-tx usr/bin
+usr/local/bin/discoin-tx usr/bin
diff --git a/contrib/debian/dogecoin-tx.manpages b/contrib/debian/dogecoin-tx.manpages
index d323ba7ef..d032ef8ff 100644
--- a/contrib/debian/dogecoin-tx.manpages
+++ b/contrib/debian/dogecoin-tx.manpages
@@ -1 +1 @@
-doc/man/dogecoin-tx.1
+doc/man/discoin-tx.1
diff --git a/contrib/debian/dogecoind.bash-completion b/contrib/debian/dogecoind.bash-completion
index dfc8b6993..db530841b 100644
--- a/contrib/debian/dogecoind.bash-completion
+++ b/contrib/debian/dogecoind.bash-completion
@@ -1,2 +1,2 @@
-contrib/dogecoind.bash-completion dogecoind
-contrib/dogecoin-cli.bash-completion dogecoin-cli
+contrib/discoind.bash-completion discoind
+contrib/discoin-cli.bash-completion discoin-cli
diff --git a/contrib/debian/dogecoind.examples b/contrib/debian/dogecoind.examples
index e6896553b..45dbdcce2 100644
--- a/contrib/debian/dogecoind.examples
+++ b/contrib/debian/dogecoind.examples
@@ -1 +1 @@
-debian/examples/dogecoin.conf
+debian/examples/discoin.conf
diff --git a/contrib/debian/dogecoind.install b/contrib/debian/dogecoind.install
index 27cb31d60..137712eb9 100644
--- a/contrib/debian/dogecoind.install
+++ b/contrib/debian/dogecoind.install
@@ -1,2 +1,2 @@
-usr/local/bin/dogecoind usr/bin
-usr/local/bin/dogecoin-cli usr/bin \ No newline at end of file
+usr/local/bin/discoind usr/bin
+usr/local/bin/discoin-cli usr/bin \ No newline at end of file
diff --git a/contrib/debian/dogecoind.lintian-overrides b/contrib/debian/dogecoind.lintian-overrides
index 6a920a350..12b24b2b8 100644
--- a/contrib/debian/dogecoind.lintian-overrides
+++ b/contrib/debian/dogecoind.lintian-overrides
@@ -1,2 +1,2 @@
# Linked code is Expat - only Debian packaging is GPL-2+
-dogecoind: possible-gpl-code-linked-with-openssl
+discoind: possible-gpl-code-linked-with-openssl
diff --git a/contrib/debian/dogecoind.manpages b/contrib/debian/dogecoind.manpages
index f2f18b37a..a02cf6ac6 100644
--- a/contrib/debian/dogecoind.manpages
+++ b/contrib/debian/dogecoind.manpages
@@ -1,2 +1,2 @@
-doc/man/dogecoind.1
-doc/man/dogecoin-cli.1
+doc/man/discoind.1
+doc/man/discoin-cli.1
diff --git a/contrib/debian/examples/dogecoin.conf b/contrib/debian/examples/dogecoin.conf
index d82492979..e8276b297 100644
--- a/contrib/debian/examples/dogecoin.conf
+++ b/contrib/debian/examples/dogecoin.conf
@@ -1,10 +1,10 @@
##
-## dogecoin.conf configuration file. Lines beginning with # are comments.
+## discoin.conf configuration file. Lines beginning with # are comments.
##
# Network-related settings:
-# Run on the test network instead of the real dogecoin network.
+# Run on the test network instead of the real discoin network.
#testnet=0
# Run a regression test network
@@ -57,10 +57,10 @@
#maxconnections=
#
-# JSON-RPC options (for controlling a running Dogecoin/dogecoind process)
+# JSON-RPC options (for controlling a running Dogecoin/discoind process)
#
-# server=1 tells Dogecoin-Qt and dogecoind to accept JSON-RPC commands
+# server=1 tells Dogecoin-Qt and discoind to accept JSON-RPC commands
#server=0
# Bind to given address to listen for JSON-RPC connections. Use [host]:port notation for IPv6.
@@ -68,7 +68,7 @@
#rpcbind=<addr>
# If no rpcpassword is set, rpc cookie auth is sought. The default `-rpccookiefile` name
-# is .cookie and found in the `-datadir` being used for dogecoind. This option is typically used
+# is .cookie and found in the `-datadir` being used for discoind. This option is typically used
# when the server and client are run as the same user.
#
# If not, you must set rpcuser and rpcpassword to secure the JSON-RPC api. The first
@@ -80,7 +80,7 @@
# using the output from the script in share/rpcuser/rpcuser.py after providing a username:
#
# ./share/rpcuser/rpcuser.py alice
-# String to be appended to dogecoin.conf:
+# String to be appended to discoin.conf:
# rpcauth=alice:f7efda5c189b999524f151318c0c86$d5b51b3beffbc02b724e5d095828e0bc8b2456e9ac8757ae3211a5d9b16a22ae
# Your password:
# DONT_USE_THIS_YOU_WILL_GET_ROBBED_8ak1gI25KFTvjovL3gAM967mies3E=
@@ -92,7 +92,7 @@
# You can even add multiple entries of these to the server conf file, and client can use any of them:
# rpcauth=bob:b2dd077cb54591a2f3139e69a897ac$4e71f08d48b4347cf8eff3815c0e25ae2e9a4340474079f55705f40574f4ec99
-# How many seconds dogecoin will wait for a complete RPC HTTP request.
+# How many seconds discoin will wait for a complete RPC HTTP request.
# after the HTTP connection is established.
#rpcclienttimeout=30
@@ -104,7 +104,7 @@
# because the rpcpassword is transmitted over the network unencrypted.
# server=1 tells Dogecoin-Qt to accept JSON-RPC commands.
-# it is also read by dogecoind to determine if RPC should be enabled
+# it is also read by discoind to determine if RPC should be enabled
#rpcallowip=10.1.1.34/255.255.255.0
#rpcallowip=1.2.3.4/24
#rpcallowip=2001:db8:85a3:0:0:8a2e:370:7334/96
@@ -112,7 +112,7 @@
# Listen for RPC connections on this TCP port:
#rpcport=22555
-# You can use Dogecoin or dogecoind to send commands to Dogecoin/dogecoind
+# You can use Dogecoin or discoind to send commands to Dogecoin/discoind
# running on another host using this option:
#rpcconnect=127.0.0.1
@@ -131,7 +131,7 @@
# both prior transactions and several dozen future transactions.
#keypool=100
-# Pay an optional transaction fee every time you send dogecoins. Transactions with fees
+# Pay an optional transaction fee every time you send discoins. Transactions with fees
# are more likely than free transactions to be included in generated blocks, so may
# be validated sooner.
#paytxfee=0.00
diff --git a/contrib/debian/rules b/contrib/debian/rules
index 6ca3d7c85..ebf79e361 100755
--- a/contrib/debian/rules
+++ b/contrib/debian/rules
@@ -1,9 +1,9 @@
#!/usr/bin/make -f
# -*- mode: makefile; coding: utf-8 -*-
-#DEB_MAKE_CHECK_TARGET = test_dogecoin
-#build/dogecoind::
-# $(if $(filter nocheck,$(DEB_BUILD_OPTIONS)),,src/test_dogecoin)
+#DEB_MAKE_CHECK_TARGET = test_discoin
+#build/discoind::
+# $(if $(filter nocheck,$(DEB_BUILD_OPTIONS)),,src/test_discoin)
%:
dh --with bash-completion $@
diff --git a/contrib/debian/watch b/contrib/debian/watch
index e81e6c040..50313e613 100644
--- a/contrib/debian/watch
+++ b/contrib/debian/watch
@@ -2,4 +2,4 @@
version=3
# use qa.debian.org redirector; see man uscan
opts=uversionmangle=s/(\d)(alpha|beta|rc)/$1~$2/,dversionmangle=s/~dfsg\d*// \
- http://githubredir.debian.net/github/dogecoin/dogecoin v(.*).tar.gz
+ http://githubredir.debian.net/github/discoin/discoin v(.*).tar.gz
diff --git a/contrib/dogecoind.bash-completion b/contrib/dogecoind.bash-completion
index f5bed8bed..addb8da5a 100644
--- a/contrib/dogecoind.bash-completion
+++ b/contrib/dogecoind.bash-completion
@@ -1,15 +1,15 @@
-# bash programmable completion for dogecoind(1) and bitcoin-qt(1)
+# bash programmable completion for discoind(1) and bitcoin-qt(1)
# Copyright (c) 2012-2016 The Bitcoin Core developers
# Distributed under the MIT software license, see the accompanying
# file COPYING or http://www.opensource.org/licenses/mit-license.php.
-_dogecoind() {
+_discoind() {
local cur prev words=() cword
- local dogecoind
+ local discoind
- # save and use original argument to invoke dogecoind for -help
+ # save and use original argument to invoke discoind for -help
# it might not be in $PATH
- dogecoind="$1"
+ discoind="$1"
COMPREPLY=()
_get_comp_words_by_ref -n = cur prev words cword
@@ -33,7 +33,7 @@ _dogecoind() {
# only parse -help if senseful
if [[ -z "$cur" || "$cur" =~ ^- ]]; then
local helpopts
- helpopts=$($dogecoind -help 2>&1 | awk '$1 ~ /^-/ { sub(/=.*/, "="); print $1 }' )
+ helpopts=$($discoind -help 2>&1 | awk '$1 ~ /^-/ { sub(/=.*/, "="); print $1 }' )
COMPREPLY=( $( compgen -W "$helpopts" -- "$cur" ) )
fi
@@ -45,7 +45,7 @@ _dogecoind() {
;;
esac
} &&
-complete -F _dogecoind dogecoind bitcoin-qt
+complete -F _discoind discoind bitcoin-qt
# Local variables:
# mode: shell-script
diff --git a/contrib/gitian-build.sh b/contrib/gitian-build.sh
index cfe4bd7d4..73c33a703 100755
--- a/contrib/gitian-build.sh
+++ b/contrib/gitian-build.sh
@@ -18,7 +18,7 @@ osx=true
SIGNER=
VERSION=
commit=false
-url=https://github.com/dogecoin/dogecoin
+url=https://github.com/discoin/discoin
proc=2
mem=2000
lxc=true
@@ -32,7 +32,7 @@ commitFiles=true
read -d '' usage <<- EOF
Usage: $scriptName [-c|u|v|b|s|B|o|h|j|m|] signer version
-Run this script from the directory containing the dogecoin, gitian-builder, gitian.sigs, and dogecoin-detached-sigs.
+Run this script from the directory containing the discoin, gitian-builder, gitian.sigs, and discoin-detached-sigs.
Arguments:
signer GPG signer to sign each build assert file
@@ -40,7 +40,7 @@ version Version number, commit, or branch to build. If building a commit or bra
Options:
-c|--commit Indicate that the version argument is for a commit or branch
--u|--url Specify the URL of the repository. Default is https://github.com/dogecoin/dogecoin
+-u|--url Specify the URL of the repository. Default is https://github.com/discoin/discoin
-v|--verify Verify the gitian build
-b|--build Do a gitian build
-s|--sign Make signed binaries for Windows and Mac OSX
@@ -246,8 +246,8 @@ then
fi
# GIT CLONE
- git clone https://github.com/dogecoin/gitian.sigs.git
- git clone https://github.com/dogecoin/dogecoin-detached-sigs.git
+ git clone https://github.com/discoin/gitian.sigs.git
+ git clone https://github.com/discoin/discoin-detached-sigs.git
git clone https://github.com/devrandom/gitian-builder.git
pushd ./gitian-builder
if [[ -n "$USE_LXC" ]]
@@ -261,7 +261,7 @@ then
fi
# Set up build
-pushd ./dogecoin
+pushd ./discoin
git fetch
git checkout ${COMMIT}
popd
@@ -270,7 +270,7 @@ popd
if [[ $build = true ]]
then
# Make output folder
- mkdir -p ./dogecoin-binaries/${VERSION}
+ mkdir -p ./discoin-binaries/${VERSION}
# Build Dependencies
echo ""
@@ -280,7 +280,7 @@ then
mkdir -p inputs
wget -N -P inputs $osslPatchUrl
wget -N -P inputs $osslTarUrl
- make -j "${proc}" -C ../dogecoin/depends download SOURCES_PATH=`pwd`/cache/common
+ make -j "${proc}" -C ../discoin/depends download SOURCES_PATH=`pwd`/cache/common
# Linux
if [[ $linux = true ]]
@@ -288,9 +288,9 @@ then
echo ""
echo "Compiling ${VERSION} Linux"
echo ""
- ./bin/gbuild -j ${proc} -m ${mem} --commit dogecoin=${COMMIT} --url dogecoin=${url} ../dogecoin/contrib/gitian-descriptors/gitian-linux.yml
- ./bin/gsign -p $signProg --signer $SIGNER --release ${VERSION}-linux --destination ../gitian.sigs/ ../dogecoin/contrib/gitian-descriptors/gitian-linux.yml
- mv build/out/dogecoin-*.tar.gz build/out/src/dogecoin-*.tar.gz ../dogecoin-binaries/${VERSION}
+ ./bin/gbuild -j ${proc} -m ${mem} --commit discoin=${COMMIT} --url discoin=${url} ../discoin/contrib/gitian-descriptors/gitian-linux.yml
+ ./bin/gsign -p $signProg --signer $SIGNER --release ${VERSION}-linux --destination ../gitian.sigs/ ../discoin/contrib/gitian-descriptors/gitian-linux.yml
+ mv build/out/discoin-*.tar.gz build/out/src/discoin-*.tar.gz ../discoin-binaries/${VERSION}
fi
# Windows
if [[ $windows = true ]]
@@ -298,10 +298,10 @@ then
echo ""
echo "Compiling ${VERSION} Windows"
echo ""
- ./bin/gbuild -j ${proc} -m ${mem} --commit dogecoin=${COMMIT} --url dogecoin=${url} ../dogecoin/contrib/gitian-descriptors/gitian-win.yml
- ./bin/gsign -p $signProg --signer $SIGNER --release ${VERSION}-win-unsigned --destination ../gitian.sigs/ ../dogecoin/contrib/gitian-descriptors/gitian-win.yml
- mv build/out/dogecoin-*-win-unsigned.tar.gz inputs/dogecoin-win-unsigned.tar.gz
- mv build/out/dogecoin-*.zip build/out/dogecoin-*.exe ../dogecoin-binaries/${VERSION}
+ ./bin/gbuild -j ${proc} -m ${mem} --commit discoin=${COMMIT} --url discoin=${url} ../discoin/contrib/gitian-descriptors/gitian-win.yml
+ ./bin/gsign -p $signProg --signer $SIGNER --release ${VERSION}-win-unsigned --destination ../gitian.sigs/ ../discoin/contrib/gitian-descriptors/gitian-win.yml
+ mv build/out/discoin-*-win-unsigned.tar.gz inputs/discoin-win-unsigned.tar.gz
+ mv build/out/discoin-*.zip build/out/discoin-*.exe ../discoin-binaries/${VERSION}
fi
# Mac OSX
if [[ $osx = true ]]
@@ -309,10 +309,10 @@ then
echo ""
echo "Compiling ${VERSION} Mac OSX"
echo ""
- ./bin/gbuild -j ${proc} -m ${mem} --commit dogecoin=${COMMIT} --url dogecoin=${url} ../dogecoin/contrib/gitian-descriptors/gitian-osx.yml
- ./bin/gsign -p $signProg --signer $SIGNER --release ${VERSION}-osx-unsigned --destination ../gitian.sigs/ ../dogecoin/contrib/gitian-descriptors/gitian-osx.yml
- mv build/out/dogecoin-*-osx-unsigned.tar.gz inputs/dogecoin-osx-unsigned.tar.gz
- mv build/out/dogecoin-*.tar.gz build/out/dogecoin-*.dmg ../dogecoin-binaries/${VERSION}
+ ./bin/gbuild -j ${proc} -m ${mem} --commit discoin=${COMMIT} --url discoin=${url} ../discoin/contrib/gitian-descriptors/gitian-osx.yml
+ ./bin/gsign -p $signProg --signer $SIGNER --release ${VERSION}-osx-unsigned --destination ../gitian.sigs/ ../discoin/contrib/gitian-descriptors/gitian-osx.yml
+ mv build/out/discoin-*-osx-unsigned.tar.gz inputs/discoin-osx-unsigned.tar.gz
+ mv build/out/discoin-*.tar.gz build/out/discoin-*.dmg ../discoin-binaries/${VERSION}
fi
popd
@@ -339,27 +339,27 @@ then
echo ""
echo "Verifying v${VERSION} Linux"
echo ""
- ./bin/gverify -v -d ../gitian.sigs/ -r ${VERSION}-linux ../dogecoin/contrib/gitian-descriptors/gitian-linux.yml
+ ./bin/gverify -v -d ../gitian.sigs/ -r ${VERSION}-linux ../discoin/contrib/gitian-descriptors/gitian-linux.yml
# Windows
echo ""
echo "Verifying v${VERSION} Windows"
echo ""
- ./bin/gverify -v -d ../gitian.sigs/ -r ${VERSION}-win-unsigned ../dogecoin/contrib/gitian-descriptors/gitian-win.yml
+ ./bin/gverify -v -d ../gitian.sigs/ -r ${VERSION}-win-unsigned ../discoin/contrib/gitian-descriptors/gitian-win.yml
# Mac OSX
echo ""
echo "Verifying v${VERSION} Mac OSX"
echo ""
- ./bin/gverify -v -d ../gitian.sigs/ -r ${VERSION}-osx-unsigned ../dogecoin/contrib/gitian-descriptors/gitian-osx.yml
+ ./bin/gverify -v -d ../gitian.sigs/ -r ${VERSION}-osx-unsigned ../discoin/contrib/gitian-descriptors/gitian-osx.yml
# Signed Windows
echo ""
echo "Verifying v${VERSION} Signed Windows"
echo ""
- ./bin/gverify -v -d ../gitian.sigs/ -r ${VERSION}-osx-signed ../dogecoin/contrib/gitian-descriptors/gitian-osx-signer.yml
+ ./bin/gverify -v -d ../gitian.sigs/ -r ${VERSION}-osx-signed ../discoin/contrib/gitian-descriptors/gitian-osx-signer.yml
# Signed Mac OSX
echo ""
echo "Verifying v${VERSION} Signed Mac OSX"
echo ""
- ./bin/gverify -v -d ../gitian.sigs/ -r ${VERSION}-osx-signed ../dogecoin/contrib/gitian-descriptors/gitian-osx-signer.yml
+ ./bin/gverify -v -d ../gitian.sigs/ -r ${VERSION}-osx-signed ../discoin/contrib/gitian-descriptors/gitian-osx-signer.yml
popd
fi
@@ -374,10 +374,10 @@ then
echo ""
echo "Signing ${VERSION} Windows"
echo ""
- ./bin/gbuild -i --commit signature=${COMMIT} ../dogecoin/contrib/gitian-descriptors/gitian-win-signer.yml
- ./bin/gsign -p $signProg --signer $SIGNER --release ${VERSION}-win-signed --destination ../gitian.sigs/ ../dogecoin/contrib/gitian-descriptors/gitian-win-signer.yml
- mv build/out/dogecoin-*win64-setup.exe ../dogecoin-binaries/${VERSION}
- mv build/out/dogecoin-*win32-setup.exe ../dogecoin-binaries/${VERSION}
+ ./bin/gbuild -i --commit signature=${COMMIT} ../discoin/contrib/gitian-descriptors/gitian-win-signer.yml
+ ./bin/gsign -p $signProg --signer $SIGNER --release ${VERSION}-win-signed --destination ../gitian.sigs/ ../discoin/contrib/gitian-descriptors/gitian-win-signer.yml
+ mv build/out/discoin-*win64-setup.exe ../discoin-binaries/${VERSION}
+ mv build/out/discoin-*win32-setup.exe ../discoin-binaries/${VERSION}
fi
# Sign Mac OSX
if [[ $osx = true ]]
@@ -385,9 +385,9 @@ then
echo ""
echo "Signing ${VERSION} Mac OSX"
echo ""
- ./bin/gbuild -i --commit signature=${COMMIT} ../dogecoin/contrib/gitian-descriptors/gitian-osx-signer.yml
- ./bin/gsign -p $signProg --signer $SIGNER --release ${VERSION}-osx-signed --destination ../gitian.sigs/ ../dogecoin/contrib/gitian-descriptors/gitian-osx-signer.yml
- mv build/out/dogecoin-osx-signed.dmg ../dogecoin-binaries/${VERSION}/dogecoin-${VERSION}-osx.dmg
+ ./bin/gbuild -i --commit signature=${COMMIT} ../discoin/contrib/gitian-descriptors/gitian-osx-signer.yml
+ ./bin/gsign -p $signProg --signer $SIGNER --release ${VERSION}-osx-signed --destination ../gitian.sigs/ ../discoin/contrib/gitian-descriptors/gitian-osx-signer.yml
+ mv build/out/discoin-osx-signed.dmg ../discoin-binaries/${VERSION}/discoin-${VERSION}-osx.dmg
fi
popd
diff --git a/contrib/gitian-descriptors/README.md b/contrib/gitian-descriptors/README.md
index 36d0a6878..3b18fcf0a 100644
--- a/contrib/gitian-descriptors/README.md
+++ b/contrib/gitian-descriptors/README.md
@@ -19,7 +19,7 @@ Sanity checks:
Once you've got the right hardware and software:
- git clone git://github.com/dogecoin/dogecoin.git
+ git clone git://github.com/discoin/discoin.git
git clone git://github.com/devrandom/gitian-builder.git
mkdir gitian-builder/inputs
cd gitian-builder/inputs
@@ -61,5 +61,5 @@ Here's a description of Gavin's setup on OSX 10.6:
5. Still inside Ubuntu, tell gitian-builder to use LXC, then follow the "Once you've got the right hardware and software" instructions above:
export USE_LXC=1
- git clone git://github.com/dogecoin/dogecoin.git
+ git clone git://github.com/discoin/discoin.git
... etc
diff --git a/contrib/gitian-descriptors/gitian-linux.yml b/contrib/gitian-descriptors/gitian-linux.yml
index 677f4be3a..2b239533c 100644
--- a/contrib/gitian-descriptors/gitian-linux.yml
+++ b/contrib/gitian-descriptors/gitian-linux.yml
@@ -1,5 +1,5 @@
---
-name: "dogecoin-linux-1.14"
+name: "discoin-linux-1.14"
enable_cache: true
suites:
- "trusty"
@@ -28,8 +28,8 @@ packages:
- "ca-certificates"
- "python"
remotes:
-- "url": "https://github.com/dogecoin/dogecoin.git"
- "dir": "dogecoin"
+- "url": "https://github.com/discoin/discoin.git"
+ "dir": "discoin"
files: []
script: |
@@ -113,7 +113,7 @@ script: |
chmod +x ${WRAP_DIR}/${prog}
done
- cd dogecoin
+ cd discoin
BASEPREFIX=`pwd`/depends
# Build dependencies for each host
for i in $HOSTS; do
@@ -135,13 +135,13 @@ script: |
./autogen.sh
CONFIG_SITE=${BASEPREFIX}/`echo "${HOSTS}" | awk '{print $1;}'`/share/config.site ./configure --prefix=/
make dist
- SOURCEDIST=`echo dogecoin-*.tar.gz`
+ SOURCEDIST=`echo discoin-*.tar.gz`
DISTNAME=`echo ${SOURCEDIST} | sed 's/.tar.*//'`
# Correct tar file order
mkdir -p temp
pushd temp
tar xf ../$SOURCEDIST
- find dogecoin-* | sort | tar --no-recursion --mode='u+rw,go+r-w,a+X' --owner=0 --group=0 -c -T - | gzip -9n > ../$SOURCEDIST
+ find discoin-* | sort | tar --no-recursion --mode='u+rw,go+r-w,a+X' --owner=0 --group=0 -c -T - | gzip -9n > ../$SOURCEDIST
popd
ORIGPATH="$PATH"
diff --git a/contrib/gitian-descriptors/gitian-osx-signer.yml b/contrib/gitian-descriptors/gitian-osx-signer.yml
index 2eb39e569..338e9cc3a 100644
--- a/contrib/gitian-descriptors/gitian-osx-signer.yml
+++ b/contrib/gitian-descriptors/gitian-osx-signer.yml
@@ -1,5 +1,5 @@
---
-name: "dogecoin-dmg-signer"
+name: "discoin-dmg-signer"
suites:
- "trusty"
architectures:
@@ -7,10 +7,10 @@ architectures:
packages:
- "faketime"
remotes:
-- "url": "https://github.com/dogecoin/dogecoin-detached-sigs.git"
+- "url": "https://github.com/discoin/discoin-detached-sigs.git"
"dir": "signature"
files:
-- "dogecoin-osx-unsigned.tar.gz"
+- "discoin-osx-unsigned.tar.gz"
script: |
WRAP_DIR=$HOME/wrapped
mkdir -p ${WRAP_DIR}
@@ -27,8 +27,8 @@ script: |
chmod +x ${WRAP_DIR}/${prog}
done
- UNSIGNED=dogecoin-osx-unsigned.tar.gz
- SIGNED=dogecoin-osx-signed.dmg
+ UNSIGNED=discoin-osx-unsigned.tar.gz
+ SIGNED=discoin-osx-signed.dmg
tar -xf ${UNSIGNED}
OSX_VOLNAME="$(cat osx_volname)"
diff --git a/contrib/gitian-descriptors/gitian-osx.yml b/contrib/gitian-descriptors/gitian-osx.yml
index e1ae624ed..ccaa6bdc8 100644
--- a/contrib/gitian-descriptors/gitian-osx.yml
+++ b/contrib/gitian-descriptors/gitian-osx.yml
@@ -1,5 +1,5 @@
---
-name: "dogecoin-osx-1.14"
+name: "discoin-osx-1.14"
enable_cache: true
suites:
- "trusty"
@@ -28,8 +28,8 @@ packages:
- "python-setuptools"
- "fonts-tuffy"
remotes:
-- "url": "https://github.com/dogecoin/dogecoin.git"
- "dir": "dogecoin"
+- "url": "https://github.com/discoin/discoin.git"
+ "dir": "discoin"
files:
- "MacOSX10.11.sdk.tar.gz"
script: |
@@ -83,7 +83,7 @@ script: |
create_per-host_faketime_wrappers "2000-01-01 12:00:00"
export PATH=${WRAP_DIR}:${PATH}
- cd dogecoin
+ cd discoin
BASEPREFIX=`pwd`/depends
mkdir -p ${BASEPREFIX}/SDKs
@@ -104,14 +104,14 @@ script: |
./autogen.sh
CONFIG_SITE=${BASEPREFIX}/`echo "${HOSTS}" | awk '{print $1;}'`/share/config.site ./configure --prefix=/
make dist
- SOURCEDIST=`echo dogecoin-*.tar.gz`
+ SOURCEDIST=`echo discoin-*.tar.gz`
DISTNAME=`echo ${SOURCEDIST} | sed 's/.tar.*//'`
# Correct tar file order
mkdir -p temp
pushd temp
tar xf ../$SOURCEDIST
- find dogecoin-* | sort | tar --no-recursion --mode='u+rw,go+r-w,a+X' --owner=0 --group=0 -c -T - | gzip -9n > ../$SOURCEDIST
+ find discoin-* | sort | tar --no-recursion --mode='u+rw,go+r-w,a+X' --owner=0 --group=0 -c -T - | gzip -9n > ../$SOURCEDIST
popd
ORIGPATH="$PATH"
diff --git a/contrib/gitian-descriptors/gitian-win-signer.yml b/contrib/gitian-descriptors/gitian-win-signer.yml
index 9c11bc89f..4345b6e80 100644
--- a/contrib/gitian-descriptors/gitian-win-signer.yml
+++ b/contrib/gitian-descriptors/gitian-win-signer.yml
@@ -1,5 +1,5 @@
---
-name: "dogecoin-win-signer"
+name: "discoin-win-signer"
suites:
- "trusty"
architectures:
@@ -8,12 +8,12 @@ packages:
- "libssl-dev"
- "autoconf"
remotes:
-- "url": "https://github.com/dogecoin/dogecoin-detached-sigs.git"
+- "url": "https://github.com/discoin/discoin-detached-sigs.git"
"dir": "signature"
files:
- "osslsigncode_1.7.1.orig.tar.gz"
- "osslsigncode-Backports-to-1.7.1.patch"
-- "dogecoin-win-unsigned.tar.gz"
+- "discoin-win-unsigned.tar.gz"
script: |
BUILD_DIR=`pwd`
SIGDIR=${BUILD_DIR}/signature/win
@@ -23,7 +23,7 @@ script: |
echo "a8c4e9cafba922f89de0df1f2152e7be286aba73f78505169bc351a7938dd911 osslsigncode-Backports-to-1.7.1.patch" | sha256sum -c
mkdir -p ${UNSIGNED_DIR}
- tar -C ${UNSIGNED_DIR} -xf dogecoin-win-unsigned.tar.gz
+ tar -C ${UNSIGNED_DIR} -xf discoin-win-unsigned.tar.gz
tar xf osslsigncode_1.7.1.orig.tar.gz
cd osslsigncode-1.7.1
diff --git a/contrib/gitian-descriptors/gitian-win.yml b/contrib/gitian-descriptors/gitian-win.yml
index 9ad12cc25..55c434851 100644
--- a/contrib/gitian-descriptors/gitian-win.yml
+++ b/contrib/gitian-descriptors/gitian-win.yml
@@ -1,5 +1,5 @@
---
-name: "dogecoin-win-1.14"
+name: "discoin-win-1.14"
enable_cache: true
suites:
- "trusty"
@@ -22,8 +22,8 @@ packages:
- "ca-certificates"
- "python"
remotes:
-- "url": "https://github.com/dogecoin/dogecoin.git"
- "dir": "dogecoin"
+- "url": "https://github.com/discoin/discoin.git"
+ "dir": "discoin"
files: []
script: |
WRAP_DIR=$HOME/wrapped
@@ -101,7 +101,7 @@ script: |
create_per-host_linker_wrapper "2000-01-01 12:00:00"
export PATH=${WRAP_DIR}:${PATH}
- cd dogecoin
+ cd discoin
BASEPREFIX=`pwd`/depends
# Build dependencies for each host
for i in $HOSTS; do
@@ -119,14 +119,14 @@ script: |
./autogen.sh
CONFIG_SITE=${BASEPREFIX}/`echo "${HOSTS}" | awk '{print $1;}'`/share/config.site ./configure --prefix=/
make dist
- SOURCEDIST=`echo dogecoin-*.tar.gz`
+ SOURCEDIST=`echo discoin-*.tar.gz`
DISTNAME=`echo ${SOURCEDIST} | sed 's/.tar.*//'`
# Correct tar file order
mkdir -p temp
pushd temp
tar xf ../$SOURCEDIST
- find dogecoin-* | sort | tar --no-recursion --mode='u+rw,go+r-w,a+X' --owner=0 --group=0 -c -T - | gzip -9n > ../$SOURCEDIST
+ find discoin-* | sort | tar --no-recursion --mode='u+rw,go+r-w,a+X' --owner=0 --group=0 -c -T - | gzip -9n > ../$SOURCEDIST
mkdir -p $OUTDIR/src
cp ../$SOURCEDIST $OUTDIR/src
popd
@@ -146,7 +146,7 @@ script: |
make ${MAKEOPTS} -C src check-security
make deploy
make install DESTDIR=${INSTALLPATH}
- cp -f dogecoin-*setup*.exe $OUTDIR/
+ cp -f discoin-*setup*.exe $OUTDIR/
cd installed
mv ${DISTNAME}/bin/*.dll ${DISTNAME}/lib/
find . -name "lib*.la" -delete
diff --git a/contrib/linearize/README.md b/contrib/linearize/README.md
index c141c21fb..3ab72c93b 100644
--- a/contrib/linearize/README.md
+++ b/contrib/linearize/README.md
@@ -20,7 +20,7 @@ standalone hash lists but safe to use with linearize-data.py, which will output
the same data no matter which byte format is chosen.
The `linearize-hashes` script requires a connection, local or remote, to a
-JSON-RPC server. Running `dogecoind` or `dogecoin-qt -server` will be sufficient.
+JSON-RPC server. Running `discoind` or `discoin-qt -server` will be sufficient.
## Step 2: Copy local block data
@@ -38,7 +38,7 @@ will be printed.
respectively, to the current time and to the timestamp of the most recent block
written to the script's blockchain.
* `genesis`: The hash of the genesis block in the blockchain.
-* `input`: dogecoind blocks/ directory containing blkNNNNN.dat
+* `input`: discoind blocks/ directory containing blkNNNNN.dat
* `hashlist`: text file containing list of block hashes created by
linearize-hashes.py.
* `max_out_sz`: Maximum size for files created by the `output_file` option.
diff --git a/contrib/linearize/example-linearize.cfg b/contrib/linearize/example-linearize.cfg
index e2d8532a7..8bad99708 100644
--- a/contrib/linearize/example-linearize.cfg
+++ b/contrib/linearize/example-linearize.cfg
@@ -1,4 +1,4 @@
-# dogecoind RPC settings (linearize-hashes)
+# discoind RPC settings (linearize-hashes)
rpcuser=someuser
rpcpassword=somepassword
host=127.0.0.1
@@ -13,12 +13,12 @@ max_height=313000
# mainnet
netmagic=c0c0c0c0
genesis=1a91e3dace36e2be3bf030a65679fe821aa1d6ef92e7c9902eb318182c355691
-input=/home/example/.dogecoin/blocks
+input=/home/example/.discoin/blocks
# testnet
#netmagic=0b110907
#genesis=bb0a78264637406b6360aad926284d544d7049f45189db5664f3c4d07350559e
-#input=/home/example/.dogecoin/testnet3/blocks
+#input=/home/example/.discoin/testnet3/blocks
# "output" option causes blockchain files to be written to the given location,
# with "output_file" ignored. If not used, "output_file" is used instead.
diff --git a/contrib/macdeploy/DS_Store b/contrib/macdeploy/DS_Store
index 4e8735081..81842ea9d 100755
--- a/contrib/macdeploy/DS_Store
+++ b/contrib/macdeploy/DS_Store
Binary files differ
diff --git a/contrib/macdeploy/custom_dsstore.py b/contrib/macdeploy/custom_dsstore.py
index 3c2a65f19..0484e17ab 100755
--- a/contrib/macdeploy/custom_dsstore.py
+++ b/contrib/macdeploy/custom_dsstore.py
@@ -45,8 +45,8 @@ alias = Alias.from_bytes(icvp['backgroundImageAlias'])
alias.volume.name = package_name_ns
alias.volume.posix_path = '/Volumes/' + package_name_ns
alias.volume.disk_image_alias.target.filename = package_name_ns + '.temp.dmg'
-alias.volume.disk_image_alias.target.carbon_path = 'Macintosh HD:Users:\x00dogecoinuser:\x00Documents:\x00dogecoin:\x00dogecoin:\x00' + package_name_ns + '.temp.dmg'
-alias.volume.disk_image_alias.target.posix_path = 'Users/dogecoinuser/Documents/dogecoin/dogecoin/' + package_name_ns + '.temp.dmg'
+alias.volume.disk_image_alias.target.carbon_path = 'Macintosh HD:Users:\x00discoinuser:\x00Documents:\x00discoin:\x00discoin:\x00' + package_name_ns + '.temp.dmg'
+alias.volume.disk_image_alias.target.posix_path = 'Users/discoinuser/Documents/discoin/discoin/' + package_name_ns + '.temp.dmg'
alias.target.carbon_path = package_name_ns + ':.background:\x00background.tiff'
icvp['backgroundImageAlias'] = biplist.Data(alias.to_bytes())
ds['.']['icvp'] = icvp
diff --git a/contrib/qos/README.md b/contrib/qos/README.md
index d16123903..ba4788f9d 100644
--- a/contrib/qos/README.md
+++ b/contrib/qos/README.md
@@ -2,4 +2,4 @@
This is a Linux bash script that will set up tc to limit the outgoing bandwidth for connections to the Dogecoin network. It limits outbound TCP traffic with a source or destination port of 22556, but not if the destination IP is within a LAN.
-This means one can have an always-on dogecoind instance running, and another local dogecoind/dogecoin-qt instance which connects to this node and receives blocks from it.
+This means one can have an always-on discoind instance running, and another local discoind/discoin-qt instance which connects to this node and receives blocks from it.
diff --git a/contrib/rpm/bitcoin.spec b/contrib/rpm/bitcoin.spec
index 39256bbc2..5bf6449cb 100644
--- a/contrib/rpm/bitcoin.spec
+++ b/contrib/rpm/bitcoin.spec
@@ -243,20 +243,20 @@ done
%if %{_buildqt}
# qt icons
-install -D -p share/pixmaps/dogecoin.ico %{buildroot}%{_datadir}/pixmaps/dogecoin.ico
+install -D -p share/pixmaps/discoin.ico %{buildroot}%{_datadir}/pixmaps/discoin.ico
install -p share/pixmaps/nsis-header.bmp %{buildroot}%{_datadir}/pixmaps/
install -p share/pixmaps/nsis-wizard.bmp %{buildroot}%{_datadir}/pixmaps/
install -p %{SOURCE100} %{buildroot}%{_datadir}/pixmaps/bitcoin.svg
-%{_bindir}/inkscape %{SOURCE100} --export-png=%{buildroot}%{_datadir}/pixmaps/dogecoin16.png -w16 -h16
-%{_bindir}/inkscape %{SOURCE100} --export-png=%{buildroot}%{_datadir}/pixmaps/dogecoin32.png -w32 -h32
-%{_bindir}/inkscape %{SOURCE100} --export-png=%{buildroot}%{_datadir}/pixmaps/dogecoin64.png -w64 -h64
-%{_bindir}/inkscape %{SOURCE100} --export-png=%{buildroot}%{_datadir}/pixmaps/dogecoin128.png -w128 -h128
-%{_bindir}/inkscape %{SOURCE100} --export-png=%{buildroot}%{_datadir}/pixmaps/dogecoin256.png -w256 -h256
-%{_bindir}/convert -resize 16x16 %{buildroot}%{_datadir}/pixmaps/dogecoin256.png %{buildroot}%{_datadir}/pixmaps/dogecoin16.xpm
-%{_bindir}/convert -resize 32x32 %{buildroot}%{_datadir}/pixmaps/dogecoin256.png %{buildroot}%{_datadir}/pixmaps/dogecoin32.xpm
-%{_bindir}/convert -resize 64x64 %{buildroot}%{_datadir}/pixmaps/dogecoin256.png %{buildroot}%{_datadir}/pixmaps/dogecoin64.xpm
-%{_bindir}/convert -resize 128x128 %{buildroot}%{_datadir}/pixmaps/dogecoin256.png %{buildroot}%{_datadir}/pixmaps/dogecoin128.xpm
-%{_bindir}/convert %{buildroot}%{_datadir}/pixmaps/dogecoin256.png %{buildroot}%{_datadir}/pixmaps/dogecoin256.xpm
+%{_bindir}/inkscape %{SOURCE100} --export-png=%{buildroot}%{_datadir}/pixmaps/discoin16.png -w16 -h16
+%{_bindir}/inkscape %{SOURCE100} --export-png=%{buildroot}%{_datadir}/pixmaps/discoin32.png -w32 -h32
+%{_bindir}/inkscape %{SOURCE100} --export-png=%{buildroot}%{_datadir}/pixmaps/discoin64.png -w64 -h64
+%{_bindir}/inkscape %{SOURCE100} --export-png=%{buildroot}%{_datadir}/pixmaps/discoin128.png -w128 -h128
+%{_bindir}/inkscape %{SOURCE100} --export-png=%{buildroot}%{_datadir}/pixmaps/discoin256.png -w256 -h256
+%{_bindir}/convert -resize 16x16 %{buildroot}%{_datadir}/pixmaps/discoin256.png %{buildroot}%{_datadir}/pixmaps/discoin16.xpm
+%{_bindir}/convert -resize 32x32 %{buildroot}%{_datadir}/pixmaps/discoin256.png %{buildroot}%{_datadir}/pixmaps/discoin32.xpm
+%{_bindir}/convert -resize 64x64 %{buildroot}%{_datadir}/pixmaps/discoin256.png %{buildroot}%{_datadir}/pixmaps/discoin64.xpm
+%{_bindir}/convert -resize 128x128 %{buildroot}%{_datadir}/pixmaps/discoin256.png %{buildroot}%{_datadir}/pixmaps/discoin128.xpm
+%{_bindir}/convert %{buildroot}%{_datadir}/pixmaps/discoin256.png %{buildroot}%{_datadir}/pixmaps/discoin256.xpm
touch %{buildroot}%{_datadir}/pixmaps/*.png -r %{SOURCE100}
touch %{buildroot}%{_datadir}/pixmaps/*.xpm -r %{SOURCE100}
diff --git a/contrib/snap/README.md b/contrib/snap/README.md
index 39dfdb725..0aa4b4a17 100644
--- a/contrib/snap/README.md
+++ b/contrib/snap/README.md
@@ -13,6 +13,6 @@ snap install \*.snap --devmode
### To Push to Snapcraft
snapcraft login
-snapcraft register dogecoin-core
+snapcraft register discoin-core
snapcraft push \*.snap --release=edge
-sudo snap install dogecoin-core --channel=edge
+sudo snap install discoin-core --channel=edge
diff --git a/contrib/snap/snapcraft.yaml b/contrib/snap/snapcraft.yaml
index ad357b142..79cf69ccb 100644
--- a/contrib/snap/snapcraft.yaml
+++ b/contrib/snap/snapcraft.yaml
@@ -1,4 +1,4 @@
-name: dogecoin-core # you probably want to 'snapcraft register <name>'
+name: discoin-core # you probably want to 'snapcraft register <name>'
version: '1.14.4'
summary: Reference client of Dogecoin, a peer-to-peer digital currency like Bitcoin.
description: |
@@ -12,45 +12,45 @@ architectures:
apps:
d:
- command: dogecoind
+ command: discoind
plugs: [home, removable-media, network, network-bind]
environment:
- # Override HOME so the datadir is located at ~/snap/dogecoin-core/common/.dogecoin/ instead of ~/snap/dogecoin-core/current/.dogecoin/, and each new version of the snap won't have a different data directory: https://docs.snapcraft.io/environment-variables/7983
+ # Override HOME so the datadir is located at ~/snap/discoin-core/common/.discoin/ instead of ~/snap/discoin-core/current/.discoin/, and each new version of the snap won't have a different data directory: https://docs.snapcraft.io/environment-variables/7983
HOME: $SNAP_USER_COMMON
qt:
- command: qt4-launch dogecoin-qt
+ command: qt4-launch discoin-qt
plugs: [home, removable-media, network, network-bind, desktop, x11, unity7]
environment:
HOME: $SNAP_USER_COMMON
DISABLE_WAYLAND: 1
cli:
- command: dogecoin-cli
+ command: discoin-cli
plugs: [home, removable-media, network]
environment:
HOME: $SNAP_USER_COMMON
parts:
- dogecoin-core:
+ discoin-core:
plugin: nil
override-build: |
echo "Downloading files..."
- wget https://github.com/dogecoin/dogecoin/releases/download/v${SNAPCRAFT_PROJECT_VERSION}/dogecoin-${SNAPCRAFT_PROJECT_VERSION}-${SNAPCRAFT_ARCH_TRIPLET}.tar.gz
- wget https://github.com/dogecoin/gitian.sigs/archive/refs/heads/master.zip
+ wget https://github.com/discoin/discoin/releases/download/v${SNAPCRAFT_PROJECT_VERSION}/discoin-${SNAPCRAFT_PROJECT_VERSION}-${SNAPCRAFT_ARCH_TRIPLET}.tar.gz
+ wget https://github.com/discoin/gitian.sigs/archive/refs/heads/master.zip
unzip master.zip
echo "Verifying secure hash matches signed values..."
- checksum=$(sha256sum dogecoin-${SNAPCRAFT_PROJECT_VERSION}-${SNAPCRAFT_ARCH_TRIPLET}.tar.gz)
+ checksum=$(sha256sum discoin-${SNAPCRAFT_PROJECT_VERSION}-${SNAPCRAFT_ARCH_TRIPLET}.tar.gz)
if ! grep -r $checksum *; then
echo "Secure hash not verified."
return
fi
- tar -xvf dogecoin-${SNAPCRAFT_PROJECT_VERSION}-${SNAPCRAFT_ARCH_TRIPLET}.tar.gz
+ tar -xvf discoin-${SNAPCRAFT_PROJECT_VERSION}-${SNAPCRAFT_ARCH_TRIPLET}.tar.gz
echo "Running tests..."
- dogecoin-${SNAPCRAFT_PROJECT_VERSION}/bin/test_dogecoin
+ discoin-${SNAPCRAFT_PROJECT_VERSION}/bin/test_discoin
echo "Installing Dogecoin..."
- install -m 0755 -D -t $SNAPCRAFT_PART_INSTALL/bin dogecoin-${SNAPCRAFT_PROJECT_VERSION}/bin/dogecoind
- install -m 0755 -D -t $SNAPCRAFT_PART_INSTALL/bin dogecoin-${SNAPCRAFT_PROJECT_VERSION}/bin/dogecoin-qt
- install -m 0755 -D -t $SNAPCRAFT_PART_INSTALL/bin dogecoin-${SNAPCRAFT_PROJECT_VERSION}/bin/dogecoin-cli
- wget https://raw.githubusercontent.com/dogecoin/dogecoin/v${SNAPCRAFT_PROJECT_VERSION}/share/pixmaps/bitcoin128.png
+ install -m 0755 -D -t $SNAPCRAFT_PART_INSTALL/bin discoin-${SNAPCRAFT_PROJECT_VERSION}/bin/discoind
+ install -m 0755 -D -t $SNAPCRAFT_PART_INSTALL/bin discoin-${SNAPCRAFT_PROJECT_VERSION}/bin/discoin-qt
+ install -m 0755 -D -t $SNAPCRAFT_PART_INSTALL/bin discoin-${SNAPCRAFT_PROJECT_VERSION}/bin/discoin-cli
+ wget https://raw.githubusercontent.com/discoin/discoin/v${SNAPCRAFT_PROJECT_VERSION}/share/pixmaps/bitcoin128.png
install -m 0644 -D -t $SNAPCRAFT_PART_INSTALL/share/pixmaps bitcoin128.png
build-packages:
- unzip
diff --git a/contrib/verify-commits/pre-push-hook.sh b/contrib/verify-commits/pre-push-hook.sh
index 4e36af4e3..acea8bf10 100755
--- a/contrib/verify-commits/pre-push-hook.sh
+++ b/contrib/verify-commits/pre-push-hook.sh
@@ -3,7 +3,7 @@
# Distributed under the MIT software license, see the accompanying
# file COPYING or http://www.opensource.org/licenses/mit-license.php.
-if ! [[ "$2" =~ ^(git@)?(www.)?github.com(:|/)dogecoin/dogecoin(.git)?$ ]]; then
+if ! [[ "$2" =~ ^(git@)?(www.)?github.com(:|/)discoin/discoin(.git)?$ ]]; then
exit 0
fi
diff --git a/contrib/devtools/gen-manpages.sh b/contrib/devtools/gen-manpages.sh
index e8838db52..d7f9e688c 100755
--- a/contrib/devtools/gen-manpages.sh
+++ b/contrib/devtools/gen-manpages.sh
@@ -4,10 +4,10 @@ TOPDIR=${TOPDIR:-$(git rev-parse --show-toplevel)}
SRCDIR=${SRCDIR:-$TOPDIR/src}
MANDIR=${MANDIR:-$TOPDIR/doc/man}
-BITCOIND=${BITCOIND:-$SRCDIR/dogecoind}
-BITCOINCLI=${BITCOINCLI:-$SRCDIR/dogecoin-cli}
-BITCOINTX=${BITCOINTX:-$SRCDIR/dogecoin-tx}
-BITCOINQT=${BITCOINQT:-$SRCDIR/qt/dogecoin-qt}
+BITCOIND=${BITCOIND:-$SRCDIR/discoind}
+BITCOINCLI=${BITCOINCLI:-$SRCDIR/discoin-cli}
+BITCOINTX=${BITCOINTX:-$SRCDIR/discoin-tx}
+BITCOINQT=${BITCOINQT:-$SRCDIR/qt/discoin-qt}
[ ! -x $BITCOIND ] && echo "$BITCOIND not found or not executable." && exit 1
@@ -15,8 +15,8 @@ BITCOINQT=${BITCOINQT:-$SRCDIR/qt/dogecoin-qt}
BTCVER=($($BITCOINCLI --version | head -n1 | awk -F'[ -]' '{ print $6, $7 }'))
# Create a footer file with copyright content.
# This gets autodetected fine for dogecoind if --version-string is not set,
# but has different outcomes for dogecoin-qt and dogecoin-cli.
echo "[COPYRIGHT]" > footer.h2m
$BITCOIND --version | sed -n '1!p' >> footer.h2m
@@ -15,8 +15,8 @@ BITCOINQT=${BITCOINQT:-$SRCDIR/qt/dogecoin-qt}
BTCVER=($($BITCOINCLI --version | head -n1 | awk -F'[ -]' '{ print $6, $7 }'))
# Create a footer file with copyright content.
-# This gets autodetected fine for dogecoind if --version-string is not set,
-# but has different outcomes for dogecoin-qt and dogecoin-cli.
+# This gets autodetected fine for discoind if --version-string is not set,
+# but has different outcomes for discoin-qt and discoin-cli.
echo "[COPYRIGHT]" > footer.h2m
$BITCOIND --version | sed -n '1!p' >> footer.h2m